#!/bin/bash
#
# Puzzle.sh
#

USAGE="Usage: $(basename $0) [-h] [<inputfile.txt> <outputfile.txt>]"

#set -x



#------------------------------------------------------- -o-
# Parse input.  
# Enforce runtime environment.
#

CLASSDIR=build/classes

INPUTFILE_DEFAULT="$(pwd)/testfiles/example-input.txt"
OUTPUTFILE_DEFAULT="$(pwd)/tmp/run-output.txt"


# Help.
#
[ "$1" = "-h" ] && {
  echo $USAGE  1>&2
  exit 1
}


# Allow no input arguments, or two for inputfile and outputfile
#
if [ $# -ne 0  -a  $# -ne 2 ]; then
  echo $USAGE  1>&2
  exit 1
fi


# If pathnames are not absolute, prefix with ../.. to return to project 
# directory (./puzzle) from ./build/class directory.
#
INPUTFILE=$1

[ -z "$INPUTFILE" ] && {
  INPUTFILE="$INPUTFILE_DEFAULT"

} || {
  [ $(expr "$INPUTFILE" : "/") -eq 0 ] && {
    INPUTFILE="../../$INPUTFILE"
  } 
}
  
OUTPUTFILE=$2

[ -z "$OUTPUTFILE" ] && {
  OUTPUTFILE="$OUTPUTFILE_DEFAULT"

} || {
  [ $(expr "$OUTPUTFILE" : "/") -eq 0 ] && {
    OUTPUTFILE="../../$OUTPUTFILE"
  } 
}


# Only run from root of project (puzzle) directory.
#
WHEREAMI=$(basename $(pwd))

[ $(expr "$WHEREAMI" : "puzzle") -le 0 ] && {
  echo "$(basename $0): Please run from the root of the puzzle directory."  1>&2
  exit 1
}



#------------------------------------------------------- -o-
# Run program.
#

cd $CLASSDIR

java Puzzle $INPUTFILE $OUTPUTFILE
RVAL=$?


exit $RVAL


