//---------------------------------------------------------------- -o--
// GTTestParseOfSection1.java 
// 
// Test error output of parse logic for Section1 of a Galactic Transaction.
//
// 
// HELPER METHODS--
//   generateOutputFileResults
//   tearDown
//
// TEST METHODS--
//   testSection1_badSplit
//   testSection1_noLines
//   testSection1_tooFewTokens
//   testSection1_badRomanNumber
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class GTTestParseOfSection1 extends TestCase
{
  //-------------------------------------------------------------- -o--
  // Helper methods.
  //

  //------------------------------ -o-
  private String  generateOutputFileResults(String inputFileName)
  {
    String  outputFileFullPathname = null;

    File    outputResultsFile  = null;
    String  outputResults      = null;


    try {
      outputFileFullPathname  = GTHelper.setFilesAndRunProgram(inputFileName);
      outputResultsFile       = new File(outputFileFullPathname);

      assertTrue( 
          "Output file EXISTS.  ("+ outputResultsFile.getName() +")", 
	  outputResultsFile.exists() );

      outputResults = 
          new String(FileUtils.readFileToString(outputResultsFile, "utf-8"));


    } catch (Exception e) {
      System.err.println("TEST ERROR IN "+ getClass() +": "+ e.toString());
    }


    return outputResults;

  } // generateOutputFileResults()



  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  @After
  protected void  tearDown()
  {
    GalacticNumber.clear();
    MaterialUnit.clear();
  }


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection1_badSplit()
  {
    String  inputFileName  = "section1-shouldFail-badSplit-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = GTHelper.BADINPUT_PREFIX + "is isoa V";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection1_badSplit()


  //------------------------------ -o-
  @org.junit.Test
  public void testSection1_noLines()
  {
    String  inputFileName  = "section1-shouldFail-noLines-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
                GTHelper.BADINPUT_PREFIX + "reos reos Titanium is 34 Credits";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection1_noLines()
  

  //------------------------------ -o-
  @org.junit.Test
  public void testSection1_tooFewTokens()
  {
    String  inputFileName  = "section1-shouldFail-tooFewTokens-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = GTHelper.BADINPUT_PREFIX + "isoa";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection1_tooFewTokens()


  //------------------------------ -o-
  @org.junit.Test
  public void testSection1_badRomanNumber()
  {
    String  inputFileName  = "section1-shouldFail-badRomanNumber-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = GTHelper.BADINPUT_PREFIX + "reos is Z";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection1_badRomanNumber()


} // class GTTestParseOfSection1

