//---------------------------------------------------------------- -o--
// MaterialUnit.java
// 
// MaterialUnit manages the dynamic list of MaterialUnit's occuring
//   in a Galactic Transaction.
//
//
// CLASS METHODS--
//   mapFromGalacticAndArabicNumerals
//   isMaterial
//   asArabicNumeral
//   clear
//
//
// DEPENDS UPON--
//   GalacticNumeral
//
//
// @version 0.1 
//

import java.util.*;



//-------------------------------------------------------------- -o--
public class MaterialUnit 
{                                                       
  private static HashMap<String, Float>  materialUnitMap = null;

  final private static String  _CLASSNAME = "MaterialUnit";

  final static String  MATERIALUNIT_ERROR =
  				_CLASSNAME +" "+ GTHelper.INPUT_ERROR;


  //
  MaterialUnit()  { }  // EMPTY



  //-------------------------------------------------------------- -o--
  // Class methods.
  //

  //---------------- -o-
  public static void  mapFromGalacticAndArabicNumerals( 
                        String  materialName, 
                        String  galacticNumeralExpression,
                        Float   creditsAsArabicNumeral)  throws GTException
  {
    GalacticNumeral  gn;
    Float            unitValueAsArabicNumeral;


    if ( (null == materialName) || (0 == materialName.length()) )
    {
      throw new GTException(MATERIALUNIT_ERROR + "Invalid material name.");
    }

    if ( (null == galacticNumeralExpression) 
           || (0 == galacticNumeralExpression.length()) )
    {
      throw new GTException(
        MATERIALUNIT_ERROR + "Invalid Galactic Numeral Expression.");
    }


    //
    if (null == materialUnitMap) {
      materialUnitMap = new HashMap<String, Float>();
    }

    if (materialUnitMap.containsKey(materialName)) {
      throw new GTException( MATERIALUNIT_ERROR 
        +"MaterialUnit "+ materialName +" is already defined.");
    }

  
    //
    try {
      gn = new GalacticNumeral(galacticNumeralExpression);

    } catch (GTException e) {
      throw new GTException( MATERIALUNIT_ERROR + e);
    }

    unitValueAsArabicNumeral  = creditsAsArabicNumeral / gn.asArabicNumeral();

    materialUnitMap.put(materialName, unitValueAsArabicNumeral);
  
  }


  //---------------- -o-
  public static Boolean  isMaterial(String materialName)
  {
    return materialUnitMap.containsKey(materialName);
  }


  //---------------- -o-
  public static Float  asArabicNumeral(String materialName)
  {
    return materialUnitMap.get(materialName);
  }
 

  //---------------- -o-
  public static void  clear() 
  { 
    if (null != materialUnitMap) {
      materialUnitMap.clear(); 
      materialUnitMap = null;
    }
  }


}  // public class MaterialUnit 

