//---------------------------------------------------------------- -o--
// Puzzle.java
//
// Application interface to commandline.  
// Parse commandline, prepare inputfile and outputfile streams.
// Invoke Puzzle class, passing it streams for input and output.
//
//
// METHODS--
//   parseCmdlineAndSetup
//   cleanup
//   main
// 
//
// @version 0.1 
//

import java.lang.*;
import java.io.*;



//---------------------------------------------------------------- -o--
public class  Puzzle 
{
  private final static String  _CLASSNAME  = "Puzzle";
  private final static String  VERSION     = "0.1";

  private final static String  USAGE       = 
      "Usage: "+ _CLASSNAME +" <inputfile> <outputfile> [true|false]";

  private static int  verbose  = 0;


  //
  private static File  inputFile,
                       outputFile;

  private static BufferedReader  inputStream;
  private static BufferedWriter  outputStream;

  private static Boolean         stdoutIsAllowed = true;
      // false indicates GalacticTransaction should generate nothing on stdout.



  //----------------------------------------------------------- -o--
  // Methods.
  // 

  //--------------------------- -o-
  private static void parseCmdlineAndSetup(String args[])
  {
    //
    if ((args.length < 2) || (args.length > 3)) {
      System.err.println(_CLASSNAME +": Incorrect number of arguments.");
      System.err.println(USAGE);
      System.exit(1);
    }


    //
    String inputFileName = args[0];
    String outputFileName = args[1];

    if (args.length > 2) {
      String stdoutIsAllowedString = args[2].trim();
      stdoutIsAllowed = ! stdoutIsAllowedString.equals("false");
    }


    inputFile = new File(inputFileName);

    if (! inputFile.isFile()) {
      System.err.println(
        _CLASSNAME +": inputfile is NOT a file.  ("+ inputFileName +")");
      System.err.println(USAGE);
      System.exit(1);

    } else if (! inputFile.canRead()) {
      System.err.println(
        _CLASSNAME +": Unable to read inputfile.  ("+ inputFileName +")");
      System.err.println(USAGE);
      System.exit(1);
    }

    outputFile = new File(outputFileName);

    if (outputFile.exists()) {
      if (verbose > 0) {
        System.err.println(_CLASSNAME 
          +": Existing outputfile will be replaced with new results.  ("
            + outputFileName +")");
      }

      if (! outputFile.delete()) {
        System.err.println(_CLASSNAME 
          +": Failed to delete pre-existing outputfile.  ("
            + outputFileName +")");
        System.err.println(USAGE);
        System.exit(1);
      }
    }

  
    try {
      inputStream = new BufferedReader(new FileReader(inputFile));
      outputStream = new BufferedWriter(new FileWriter(outputFile));

    } catch (Exception e) {
      System.err.println(_CLASSNAME +": "+ e.toString());
      System.exit(1);
    }
    
  } // parseCmdlineAndSetup()



  //--------------------------- -o-
  private static void cleanup()
  {
    try {
      inputStream.close();

      outputStream.flush();
      outputStream.close();

    } catch (Exception e) {
      System.err.println(_CLASSNAME +": "+ e.toString());
      System.exit(1);
    }
  } 



  //----------------------------------------------------------- -o--
  public static void main(String args[]) 
  {
    Integer rval = 0;
    
    parseCmdlineAndSetup(args);


    try {
      GalacticTransaction galacticTransaction = 
        new GalacticTransaction(inputStream, outputStream, stdoutIsAllowed);

      rval = galacticTransaction.main();

    } catch (Exception e) {
      System.err.println(_CLASSNAME +": "+ e.toString());
      System.exit(1);
    }


    cleanup();

    System.exit(rval);

  }  // main()
  
} // class Puzzle()

